@@ -163,4 +163,10 @@ def volume_weighted_high_low_vol_long_only(data = None , vol_threshold = 0.05, u
         else:
             return np.nan
     else :
-        return np.nan
\ No newline at end of file
+        return np.nan
+
+
+
+def slope_induced(data = None, slope_column = 'high', contravariant = -1., **kwargs):
+    high_slope = (data[slope_column][-1] - data[slope_column][0]) / len(data)
+    return contravariant*high_slope
\ No newline at end of file
