@@ -57,4 +57,7 @@ def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_c
     else :
         data['perf_return'] = data['non_adjusted_perf_return']
     data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
-    return data
\ No newline at end of file
+    return data
+
+def compute_turn_over(data=None):
+    return abs((data.signal - data.signal.shift(-1).fillna(0.))).mean()
\ No newline at end of file
